@@ -109,7 +109,7 @@ class Filters():
         return images_transform
 
 
-    def filter_gaussiano_all(self, sigmaradius = 3.0, folder = None):
+    def filter_gaussiano_all(self, kernel = 3, folder = None):
 
         '''
         Esta função é responsável por gerar uma pasta contendo contendo as imagens de entrada em imagens 
@@ -118,7 +118,8 @@ class Filters():
         Parâmetros
         ==========
 
-        sigmaradius : float
+        kernel : int
+            ajustar a regulagem do desfoque
 
         folder : srt
             Endereço da pasta na qual o usuário deseja salvar as imagens processadas 
@@ -131,8 +132,6 @@ class Filters():
 
         '''
         
-
-
         if not os.path.exists(folder):
             os.makedirs(folder)
 
@@ -144,7 +143,7 @@ class Filters():
         for i in images_all:
             image = imread(i)
             output = self.rename_file(i)
-            image = cv2.GaussianBlur(image,( 3, 3 ), sigmaradius)
+            image = cv2.GaussianBlur(image,(kernel, kernel),cv2.BORDER_DEFAULT)
             images_transform.append(image)
             folder_aux = folder + '\\Gaussiano_' + output
             print(folder_aux)
@@ -382,7 +381,7 @@ class Filters():
             
             return images_transform
 
-    def transform_ugc(self,folder = None, sigmaradius = 3.0,kernel_size = 127 ,nbins = 256):
+    def transform_ugc(self,folder = None, kernel = 3,kernel_size = 127 ,nbins = 256):
 
         '''
 
@@ -396,12 +395,14 @@ class Filters():
         folder : str
             Nome da pasta na qual o usuário deseja salavar as novas imagens
 
-        sigmaradius : float
+        kernel : int
+            ajuste de desfoque no filtro gaussiano
 
         kernel_size : int
-            Representa o tamanho da janela   para aplicar  filtro
+            Representa o tamanho da janela   para aplicar  filtro no clahe
 
         nbins : int
+            ajuste para o clahe
 
         Returns
         =======
@@ -426,7 +427,7 @@ class Filters():
             output = self.rename_file(i)
             image = cv2.cvtColor(image , cv2.COLOR_BGR2LUV)
             l,u,v = cv2.split(image)
-            u =  cv2.GaussianBlur(u,( 3, 3 ),sigmaradius)
+            u =  cv2.GaussianBlur(u,( kernel, kernel ),cv2.BORDER_DEFAULT)
             u = (u).astype('uint8')
             u = skimage.exposure.equalize_adapthist(u, kernel_size = kernel_size, nbins = nbins)
             images_transform.append(u)
@@ -476,7 +477,7 @@ class Filters_uniq():
         return image
 
 
-    def filter_gaussiano(self, image, sigmaradius = 3.0):
+    def filter_gaussiano(self, image, kernel = 3):
 
         '''
 
@@ -488,7 +489,8 @@ class Filters_uniq():
         image : str 
             Endereço da imagem que o usário deseja fazer a transição
         
-        sigmaradius : float
+        kernel : int
+            ajuste do desfoque
         
 
         Returns
@@ -500,7 +502,7 @@ class Filters_uniq():
         '''
 
         image = imread(image)
-        image = cv2.GaussianBlur(image,( 3, 3 ),sigmaradius)
+        image = cv2.GaussianBlur(image,( kernel, kernel ),cv2.BORDER_DEFAULT)
 
         return image
 
